let isInitializing = false;
let isInitialized = false;
const loadFormbricksSDK = async (apiHostParam) => {
  if (!window.feedbackflow) {
    const scriptTag = document.createElement("script");
    scriptTag.type = "text/javascript";
    scriptTag.src = `${apiHostParam}/js/feedbackflow.umd.cjs`;
    scriptTag.async = true;
    const getFormbricks = async () => new Promise((resolve, reject) => {
      const timeoutId = setTimeout(() => {
        reject(new Error(`Feedbackflow SDK loading timed out`));
      }, 1e4);
      scriptTag.onload = () => {
        clearTimeout(timeoutId);
        resolve();
      };
      scriptTag.onerror = () => {
        clearTimeout(timeoutId);
        reject(new Error(`Failed to load Feedbackflow SDK`));
      };
    });
    document.head.appendChild(scriptTag);
    try {
      await getFormbricks();
      return { ok: true, data: void 0 };
    } catch (error) {
      const err = error;
      return {
        ok: false,
        error: new Error(err.message ?? `Failed to load Feedbackflow SDK`)
      };
    }
  }
  return { ok: true, data: void 0 };
};
const functionsToProcess = [];
const loadFormbricksToProxy = async (prop, ...args) => {
  if (!isInitialized) {
    if (prop === "setup") {
      if (isInitializing) {
        console.warn("🧱 Feedbackflow - Warning: Feedbackflow is already initializing.");
        return;
      }
      isInitializing = true;
      const argsTyped = args[0];
      const { appUrl, environmentId } = argsTyped;
      if (!appUrl) {
        console.error("🧱 Feedbackflow - Error: appUrl is required");
        return;
      }
      if (!environmentId) {
        console.error("🧱 Feedbackflow - Error: environmentId is required");
        return;
      }
      const loadSDKResult = await loadFormbricksSDK(appUrl);
      if (loadSDKResult.ok) {
        if (window.feedbackflow) {
          const formbricksInstance = window.feedbackflow;
          void formbricksInstance.setup(...args);
          isInitializing = false;
          isInitialized = true;
          for (const { prop: functionProp, args: functionArgs } of functionsToProcess) {
            if (typeof formbricksInstance[functionProp] !== "function") {
              console.error(`🧱 Feedbackflow - Error: Method ${functionProp} does not exist on feedbackflow`);
              continue;
            }
            formbricksInstance[functionProp](...functionArgs);
          }
        }
      }
    } else {
      console.warn(
        "🧱 Feedbackflow - Warning: Feedbackflow not initialized. This method will be queued and executed after initialization."
      );
      functionsToProcess.push({ prop, args });
    }
  } else if (window.feedbackflow) {
    const formbricksInstance = window.feedbackflow;
    const functionPropTyped = prop;
    await formbricksInstance[functionPropTyped](...args);
  }
};
const formbricksProxyHandler = {
  get(_target, prop, _receiver) {
    return (...args) => loadFormbricksToProxy(prop, ...args);
  }
};
const feedbackflow = new Proxy({}, formbricksProxyHandler);
export {
  feedbackflow as default
};
//# sourceMappingURL=index.js.map
